@@ -7,7 +7,7 @@ size(IntroWindow)<-c(800,600)
 IntroTextframe<-gframe(horizontal = FALSE, container=IntroWindow,where="center")
 IntroTextMessage1<-glabel('Welcome to StatCharrms',container=IntroTextframe,where="center") #Title1
 font(IntroTextMessage1)<-list(size=34)
-IntroTextMessage2<-glabel('v0.90.8 March 27, 2018',container=IntroTextframe,where="center") #Title2  #Update This
+IntroTextMessage2<-glabel('v0.90.9 April 5, 2018',container=IntroTextframe,where="center") #Title2  #Update This
 font(IntroTextMessage2)<-list(size=16)
 IntroTextMessage3<-glabel('Beta -Developmental-',container=IntroTextframe,where="center") #Title2
 font(IntroTextMessage3)<-list(size=16)
